#!/usr/bin/perl
use strict;
use warnings;

# this scripts opens two text files containing a list of sequence motifs and loops through a fasta file searching for each motif.
# Requires "left_motif_list.txt" and "right_motif_list.txt" to be present. These 2 files should have no extra lines after the last motif in the list!
# Version 2 - arranged for each motif file to be labelled with the name of the fasta file used to generate it.

unless (exists $ARGV[0]) {print "\n\n\n MODIFY THE MOTIFS BEFORE RUNNING!!!\n\n[Fasta file to search] [minimum spacer between motifs # amino acids]\n\n\n";exit;} # file to search

my $left_motif=(0);
my $right_motif=(0);
my $leftarraytotal= (0);
my $rightarraytotal= (0);

my $spacer_size = $ARGV[1];

#open list of left motifs and populate array
open (LEFTMOTIFLIST, "<left_motif_list.txt") or die "can't open left list: $!";
my @left_list = <LEFTMOTIFLIST>;
chomp @left_list;
close LEFTMOTIFLIST;

#open list of right motifs and populate array
open (RIGHTMOTIFLIST, "<right_motif_list.txt") or die "can't open right list: $!";
my @right_list= <RIGHTMOTIFLIST>;
chomp @right_list;
close RIGHTMOTIFLIST;

# moved the following 2 lines here so there is only 1 header in the log
open LOG, ">>$ARGV[0]\.Motif.log";
print LOG "Sequence\tSequence_Count\tL+R_Motif\tL_motif_only\tR_motif_only\tLeft\tRight\tPercentageLandR\n";

my $sequenceL=0;
my $sequenceR=0;

#loop through each of the left motifs and right motifs:

foreach $sequenceL (@left_list){
	foreach $sequenceR (@right_list){
		$left_motif = $sequenceL;
		$right_motif = $sequenceR;


my $file = $ARGV[0];
my $short = $ARGV[0];
if ($short =~ /.*\/(.*)/){$short = $1};


# IUPAC degeneracy lookup table
my %IUPAC = (
A => 'A',C => 'C', G => 'G', T => 'T', U => 'U',
R => '[AG]', Y => '[CTU]', M => '[CA]', K => '[TUG]',
W => '[TUA]', S => '[CG]', B => '[CTUG]', D => '[ATUG]',
H => '[ATUC]', V => '[ACG]', N => '[ACGTU]');


my $count = 0;
my $hitcount = 0;
my $lefthitcount = 0;
my $righthitcount = 0;
my $PercentLandR = 0;

open OUT1, ">>$short\.LR.fa";
open OUT2, ">>$short\.L.fa";
open OUT3, ">>$short\.R.fa";


open FASTA, "$file";
{
local $/ = '>'; 
<FASTA>;
	while (<FASTA>)
	{
	$count++;
	my($id, @seq) = split "\n";
   	my $seq = join '', @seq;
	if ($seq =~ />$/){$seq =~ s/>//;}
   	
	if ($seq =~ /$left_motif(.{$spacer_size,}?)$right_motif/)
		{
		print OUT1 "\>$id\n$1\n";
		$hitcount++;
		}
	elsif ($seq =~ /$left_motif(.{$spacer_size,})/) 
		{
		print OUT2 "\>$id\n$1\n";
		$lefthitcount++;
		}
	elsif ($seq =~ /(.$spacer_size,})$right_motif/)
		{
		print OUT3 "\>$id\n$1\n";
		$righthitcount++;
		
		
		$PercentLandR = sprintf("%.2f", ($hitcount/$count*100));
		}	
	}
}




open LOG, ">>$ARGV[0]\.Motif.log";
print LOG "$short\t$count\t$hitcount\t$lefthitcount\t$righthitcount\t$left_motif\t$right_motif\t$PercentLandR\n";

#generate a log of all the motif combinations tested:
open OUT0, ">>$ARGV[0]\.Motifs_tested.log";
print OUT0 "$left_motif\t$right_motif\n";

close FASTA;
close OUT0;
close OUT1;
close OUT2;
close OUT3;

	
	
}
}


close LOG;
	



